VersionComparator

Type Alias VersionComparator 

pub type VersionComparator = Arc<dyn Fn(Version, RemoteRelease) -> bool + Send + Sync + 'static>;
Custom version comparator used to override the default semver > update check.

The closure receives the current application version and the fetched remote release model. Return true to treat the release as an update.

Aliased Type

pub struct VersionComparator { /* private fields */ }